@@ -1,21 +1,23 @@
 from deephys.deephys import (
-    ImageFile,
     Neuron,
     Layer,
     Model,
-    Test,
-    Stopwatch,
+    model,
     import_torch_dataset,
     import_test_data,
+    ImageFile,
+    Test,
+    Stopwatch,
 )
 
 __all__ = [
-    "ImageFile",
     "Neuron",
     "Layer",
     "Model",
-    "Test",
-    "Stopwatch",
+    "model",
     "import_torch_dataset",
     "import_test_data",
+    "ImageFile",
+    "Test",
+    "Stopwatch",
 ]
